Licensed businesses for sale in UK - Pubs for sale, Hotels and Restaurants for Sale,
Author: Sidney Phillips
Description: UK based licensed business agents offering pubs for sale and other licensed premises including night clubs and discos. Properties include urban pubs and roadside inns.
Keywords: pubs for sale, commercial letting agents, uk, freeholds, leaseholds, tenancies, public houses, licensed premises, discos, clubs, inns, taverns, rural, urban, city centre, locations, sales, transfers

accessibility | skip nav
Home | Login | Register
08454 585 900
Search for information
or
Property Quick Search

# Full details

« back to search results

Ref: 36993
Leasehold Capital required £30,000

- BRIGANDS INN NR MACHYNLLETH POWYS
- Landmark 15th Century Inn/Hotel
- Super appointed character premises
- 2 bars/restaurants/function suite
- 9 e/s letting rooms. Manager's flat
- Landscaped grounds. Parking
- Net sales £500K+. Captive trade

## Property Details and Shortlist

You must be registered and logged in to view the details or create a shortlist. Login now! or if you have not already created an account, register now!